@@ -40,7 +40,7 @@ metadata = {'creator': {'name': 'Unknown',
                             },
             'reduction': {'software': {'name': 'islatu',
                                        'link': 'https://islatu.readthedocs.io',
-                                       'version': '0.0.39'},
+                                       'version': '0.0.40'},
                           'yaml': 'Unknown',
                           'input files': {'datafiles': []},
                           'data state': {}}
@@ -223,7 +223,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=met
         elif the_boss.q_space == 'log':
             spacing = np.logspace
         refl.rebin(new_q=spacing(the_boss.q_min, the_boss.q_max, the_boss.q_step))
-    the_boss.metadata['reduction']['data state']['rebinned'] = the_boss.q_space
+    the_boss.metadata['reduction']['data state']['rebinned'] = the_boss.q_shape
 
     the_boss.metadata['data source']['experiment']['measurement']['q range'] = [refl.q.min(), refl.q.max()]
     the_boss.metadata['data']['column 1'] = 'Qz / Aa^-1'
@@ -231,11 +231,11 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=met
     the_boss.metadata['data']['column 3'] = 'sigma RQz, standard deviation'
     if the_boss.output_columns == 3:
         data = np.array([refl.q, refl.R, refl.dR]).T
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}'.format(yaml.dumps(the_boss.metadata)))
+        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3'.format(yaml.dumps(the_boss.metadata)))
     elif the_boss.output_columns == 4:
         data = np.array([refl.q, refl.R, refl.dR, refl.dq]).T
         the_boss.metadata['data']['column 4'] = 'sigma Qz / Aa^-1, standard deviation'
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}'.format(yaml.dumps(the_boss.metadata)))
+        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3 4'.format(yaml.dumps(the_boss.metadata)))
     print("-" * 10)
     print('Reduced Data Stored in Processing Directory')
     print("-" * 10)
